part of katana_module;

/// Module adapter for setting up purchasing.
///
/// [PurchaseAdapter] can switch the data
/// when the module is used by passing it to [UIMaterialApp].
@immutable
abstract class PurchaseAdapter extends Module {
  const PurchaseAdapter();

  /// Class for managing billing process.
  ///
  /// Initialize by first executing [initialize()].
  ///
  /// Then purchasing item by executing [purchase()].
  Future<void> initialize({
    required List<PurchaseProduct> products,
  });

  /// Restore purchase.
  ///
  /// Please use it manually or immediately after user registration.
  Future<void> restore();

  /// Consume all purchased items.
  ///
  /// Please use it manually or immediately after user registration.
  Future<void> consume(String productId);

  /// Process the purchase.
  ///
  /// You specify the item ID in [id], the billing process will start.
  Future<void> purchase(
    String id, {
    String? applicationUserName,
    bool sandboxTesting = false,
  });

  /// Get the [PurchaseProduct] list.
  List<PurchaseProduct> getProducts();

  /// Find the [PurchaseProduct] from [ProductId].
  PurchaseProduct? getProduct(String productId);

  /// Find the [PurchaseProduct] from [ProductId].
  PurchaseProduct? findById(String productId);
}
