part of katana_module;

/// Product type.
enum ProductType {
  /// Consumable.
  consumable,

  /// Non-Consumable.
  nonConsumable,

  /// Subscription.
  subscription
}

/// Class for storing information for billing purposes.
abstract class PurchaseProduct {
  /// Class for storing information for billing purposes.
  const PurchaseProduct({
    required this.id,
    this.type = ProductType.consumable,
    this.value = 0,
    this.targetPath,
  });

  /// Basement id.
  final String id;

  /// Product type.
  final ProductType type;

  /// Product value.
  final double value;

  /// Target path.
  final String? targetPath;

  /// Check out if non-consumption items and subscriptions are valid.
  ///
  /// If true, billing is enabled.
  bool get enabled;

  /// Product Id.
  String get productId;

  /// The name of the item.
  String get productName;

  /// Item description.
  String get productDescription;

  /// The price of the item.
  String get productPrice;

  /// Convert the purchase product to [DynamicMap].
  DynamicMap toMap();

  /// Convert the purchase product from [DynamicMap].
  PurchaseProduct? fromMap(DynamicMap map);
}
